import { Box, Button, Flex } from '@chakra-ui/react';

interface PaginationProps {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
}

export default function Pagination({
  currentPage,
  totalPages,
  onPageChange,
}: PaginationProps) {
  const createPageArray = () => {
    const pages = [];
    for (let i = 1; i <= totalPages; i++) {
      pages.push(i);
    }
    return pages;
  };

  return (
    <Flex justify="center" mt={10} wrap="wrap" gap={2}>
      <Button
        onClick={() => onPageChange(currentPage - 1)}
        isDisabled={currentPage === 1}
        size="sm"
        variant="outline"
      >
        Previous
      </Button>

      {createPageArray().map((page) => (
        <Button
          key={page}
          onClick={() => onPageChange(page)}
          size="sm"
          variant={currentPage === page ? 'solid' : 'outline'}
          colorScheme={currentPage === page ? 'teal' : 'gray'}
        >
          {page}
        </Button>
      ))}

      <Button
        onClick={() => onPageChange(currentPage + 1)}
        isDisabled={currentPage === totalPages}
        size="sm"
        variant="outline"
      >
        Next
      </Button>
    </Flex>
  );
}
